==> openconfig-models-16.0.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/openflow/rev181121/$YangModuleInfoImpl.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.openflow.rev181121;

import com.google.common.collect.ImmutableSet;
import java.lang.Override;
import java.lang.String;
import java.util.HashSet;
import java.util.Set;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yangtools.yang.binding.ResourceYangModuleInfo;
import org.opendaylight.yangtools.yang.binding.YangModuleInfo;
import org.opendaylight.yangtools.yang.common.QName;

@javax.annotation.processing.Generated("mdsal-binding-generator")
public final class $YangModuleInfoImpl extends ResourceYangModuleInfo {
    private static final @NonNull QName NAME = QName.create("http://openconfig.net/yang/openflow", "2018-11-21", "openconfig-openflow").intern();
    private static final @NonNull YangModuleInfo INSTANCE = new $YangModuleInfoImpl();

    private final @NonNull ImmutableSet<YangModuleInfo> importedModules;

    public static @NonNull YangModuleInfo getInstance() {
        return INSTANCE;
    }

    public static @NonNull QName qnameOf(final String localName) {
        return QName.create(NAME, localName).intern();
    }

    private $YangModuleInfoImpl() {
        Set<YangModuleInfo> set = new HashSet<>();
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.openconfig.ext.rev200616.$YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.types.inet.rev210107.$YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.interfaces.rev210406.$YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.openflow.types.rev200630.$YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.rev200413.$YangModuleInfoImpl.getInstance());
        importedModules = ImmutableSet.copyOf(set);
    }
    
    @Override
    public QName getName() {
        return NAME;
    }
    
    @Override
    protected String resourceName() {
        return "/META-INF/yang/openconfig-openflow@2018-11-21.yang";
    }
    
    @Override
    public ImmutableSet<YangModuleInfo> getImportedModules() {
        return importedModules;
    }
}

==> openconfig-models-17.4.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/openflow/rev181121/$YangModuleInfoImpl.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.openflow.rev181121;

import com.google.common.collect.ImmutableSet;
import java.lang.Override;
import java.lang.String;
import java.util.HashSet;
import java.util.Set;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yangtools.yang.binding.ResourceYangModuleInfo;
import org.opendaylight.yangtools.yang.binding.YangModuleInfo;
import org.opendaylight.yangtools.yang.common.QName;

/**
 * The {@link ResourceYangModuleInfo} for {@code openconfig-openflow} module.
 */
@javax.annotation.processing.Generated("mdsal-binding-generator")
public final class $YangModuleInfoImpl extends ResourceYangModuleInfo {
    private static final @NonNull QName NAME = QName.create("http://openconfig.net/yang/openflow", "2018-11-21", "openconfig-openflow").intern();
    private static final @NonNull YangModuleInfo INSTANCE = new $YangModuleInfoImpl();

    private final @NonNull ImmutableSet<YangModuleInfo> importedModules;

    /**
     * Return the singleton instance of this class.
     *
     * @return The singleton instance
     */
    public static @NonNull YangModuleInfo getInstance() {
        return INSTANCE;
    }

    /**
     * Create an interned {@link QName} with specified {@code localName} and namespace/revision of this
     * module.
     *
     * @param localName local name
     * @return A QName
     * @throws NullPointerException if {@code localName} is null
     * @throws IllegalArgumentException if localName is not a valid YANG identifier
     */
    public static @NonNull QName qnameOf(final String localName) {
        return QName.create(NAME, localName).intern();
    }

    private $YangModuleInfoImpl() {
        Set<YangModuleInfo> set = new HashSet<>();
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.openconfig.ext.rev200616.$YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.types.inet.rev210107.$YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.interfaces.rev210406.$YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.openflow.types.rev200630.$YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.rev200413.$YangModuleInfoImpl.getInstance());
        importedModules = ImmutableSet.copyOf(set);
    }
    
    @Override
    public QName getName() {
        return NAME;
    }
    
    @Override
    protected String resourceName() {
        return "/META-INF/yang/openconfig-openflow@2018-11-21.yang";
    }
    
    @Override
    public ImmutableSet<YangModuleInfo> getImportedModules() {
        return importedModules;
    }
}
